pub enum OKXRpiPermission {
Disabled,
Enabled,
Permitted,
}Expand description
Represents an account’s RPI permission for an instrument.
Variants
Disabled
RPI is not enabled for the instrument.
Enabled
RPI is enabled, but the account cannot place RPI orders.
Permitted
RPI is enabled and the account can place RPI orders.